# athena-udf

[![PyPI](https://img.shields.io/pypi/v/athena-udf.svg)](https://pypi.org/project/athena-udf/)
[![Changelog](https://img.shields.io/github/v/release/dmarkey/athena-udf?include_prereleases&label=changelog)](https://github.com/dmarkey/athena-udf/releases)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/dmarkey/athena-udf/blob/main/LICENSE)

Athena User Defined Functions(UDFs) made easy!

## Installation

Install this library using `pip`:

    pip install athena-udf

## Usage

Usage instructions go here.

## Development

To contribute to this library, first checkout the code. Then create a new virtual environment:

    cd athena-udf
    python -m venv venv
    source venv/bin/activate

Now install the dependencies and test dependencies:

    pip install -e '.[test]'

To run the tests:

    pytest
